﻿using SDON.Serialization;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;
using System.Threading.Tasks;

namespace SDON
{
    /// <summary>
    /// Object that represents a row of column values in a DataTable.
    /// </summary>
    [Serializable]
    public sealed class DataRow : SDONSerializeable
    {
        [IgnoreIfDefaultValue(Default = null)]
        [DataMember(Name = "RowID")]
        private string _rowID = null;

        [IgnoreIfDefaultValue(Default = null)]
        [DataMember(Name = "Fields")]
        private List<DataField> _fields = null;

        /// <summary>
        /// The ID of the row.
        /// </summary>
        public string RowID
        {
            get { return _rowID; }
            set { _rowID = value; }
        }

        /// <summary>
        /// A list of fields that are used to populate a row in a DataTable schema defined in the Diagram object.
        /// </summary>
        public List<DataField> Fields
        {
            get { return _fields; }
            set { _fields = value; }
        }

        /// <summary>
        /// A list of fields that are used to populate a row in a DataTable schema defined in the Diagram object.
        /// </summary>
        public DataRow SetValues(DataField[] fields)
        {
            if (_fields == null)
                _fields = new List<DataField>();

            foreach (DataField field in fields)
            {
                _fields.Add(field);
            }

            return this;
        }
    }
}
